stepfor: stepfor.Rd

Description Usage Arguments Examples

Description

When choosing 'd', and d is a dataframe, then the entire dataframe can be used (look at example), although when this is the case you have to make sure the dependent variable is de-selected

Usage

1
stepfor(y = y, d = d, alpha = 0.05)

Arguments

y

dependent variable for selection

d

select the independent variables

Examples

1
2
data(weight)
stepfor(weight$wgt, weight[, -1], alpha = 0.2)

lime-n/Stepfor-package documentation built on Dec. 21, 2021, 10:50 a.m.