Description Usage Arguments Examples
When choosing 'd', and d is a dataframe, then the entire dataframe can be used (look at example), although when this is the case you have to make sure the dependent variable is de-selected
1 | stepfor(y = y, d = d, alpha = 0.05)
|
y |
dependent variable for selection |
d |
select the independent variables |
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.